==> svelte-floating-ui-0.1.7.tgz: package/index.js <==
import { arrow as arrowCore } from "@floating-ui/core";
import { computePosition } from "@floating-ui/dom";
import { get } from "svelte/store";
export function createFloatingActions(initOptions) {
    let referenceElement;
    let contentElement;
    let options = initOptions;
    const events = {
        handler() {
            updatePosition();
        },
        init() {
            window.addEventListener('scroll', this.handler);
            window.addEventListener('resize', this.handler);
        },
        destroy() {
            window.removeEventListener('scroll', this.handler);
            window.removeEventListener('resize', this.handler);
        }
    };
    const updatePosition = (updateOptions) => {
        if (referenceElement && contentElement) {
            options = { ...initOptions, ...updateOptions };
            computePosition(referenceElement, contentElement, options)
                .then(v => {
                Object.assign(contentElement.style, {
                    position: v.strategy,
                    left: `${v.x}px`,
                    top: `${v.y}px`,
                });
                options?.onComputed && options.onComputed(v);
            });
        }
    };
    const referenceAction = node => {
        referenceElement = node;
        updatePosition();
        return {
            destroy() {
                events.destroy();
            }
        };
    };
    const contentAction = (node, contentOptions) => {
        contentElement = node;
        options = { ...initOptions, ...contentOptions };
        updatePosition();
        events.init();
        return {
            update: updatePosition,
            destroy() {
                events.destroy();
            }
        };
    };
    return [
        referenceAction,
        contentAction,
        updatePosition
    ];
}
export function arrow(options) {
    return {
        name: "arrow",
        options,
        fn(args) {
            const element = get(options.element);
            if (element) {
                return arrowCore({
                    element,
                    padding: options.padding
                }).fn(args);
            }
            return {};
        }
    };
}

==> svelte-floating-ui-0.2.1.tgz: package/index.js <==
import { arrow as arrowCore } from "@floating-ui/core";
import { autoUpdate as _autoUpdate, computePosition } from "@floating-ui/dom";
import { get } from "svelte/store";
export function createFloatingActions(initOptions) {
    let referenceElement;
    let floatingElement;
    let options = initOptions;
    const updatePosition = (updateOptions) => {
        if (referenceElement && floatingElement) {
            options = { ...initOptions, ...updateOptions };
            computePosition(referenceElement, floatingElement, options)
                .then(v => {
                Object.assign(floatingElement.style, {
                    position: v.strategy,
                    left: `${v.x}px`,
                    top: `${v.y}px`,
                });
                options?.onComputed && options.onComputed(v);
            });
        }
    };
    const referenceAction = node => {
        referenceElement = node;
        updatePosition();
    };
    const contentAction = (node, contentOptions) => {
        let autoUpdateDestroy;
        floatingElement = node;
        options = { ...initOptions, ...contentOptions };
        updatePosition();
        if (options.autoUpdate !== false) {
            autoUpdateDestroy = _autoUpdate(referenceElement, floatingElement, () => updatePosition(), options.autoUpdate);
        }
        return {
            update: updatePosition,
            destroy() {
                autoUpdateDestroy && autoUpdateDestroy();
            }
        };
    };
    return [
        referenceAction,
        contentAction,
        updatePosition
    ];
}
export function arrow(options) {
    return {
        name: "arrow",
        options,
        fn(args) {
            const element = get(options.element);
            if (element) {
                return arrowCore({
                    element,
                    padding: options.padding
                }).fn(args);
            }
            return {};
        }
    };
}
